@@ -1,7 +1,7 @@
 package IPC::System::Options;
 
-our $DATE = '2015-02-07'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2015-04-15'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -50,9 +50,14 @@ sub _system_or_backtick {
     if ($which eq 'system') {
 
         $log->tracef("system(%s)", \@_) if $opts->{log};
-        if (defined($opts->{shell}) && !$opts->{shell}) {
+        if ($opts->{shell}) {
+            # force the use of shell
+            $res = system join(" ", @_);
+        } elsif (defined $opts->{shell}) {
+            # forbid shell
             $res = system {$_[0]} @_;
         } else {
+            # might or might not use shell (if @_ == 1)
             $res = system @_;
         }
 
@@ -131,7 +136,7 @@ IPC::System::Options - Perl's system() and backtick/qx replacement/wrapper, with
 
 =head1 VERSION
 
-This document describes version 0.06 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-02-07.
+This document describes version 0.07 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-04-15.
 
 =head1 SYNOPSIS
 
